pub enum IdParseError {
InvalidProcId(UidParseError),
InvalidActorIdFormat,
InvalidActorUid(UidParseError),
InvalidActorProcUid(UidParseError),
InvalidPortIdFormat,
InvalidPort(String),
}Variants
InvalidProcId(UidParseError)
Error parsing a ProcId.
InvalidActorIdFormat
Error parsing an ActorId (missing . separator).
InvalidActorUid(UidParseError)
Error parsing the actor uid component of an ActorId.
InvalidActorProcUid(UidParseError)
Error parsing the proc uid component of an ActorId.
InvalidPortIdFormat
The <actor_id>:<port> separator is missing.
InvalidPort(String)
The port component is invalid.